# Changelog

## [2.1.0](https://github.com/camoag/omni-sdk/compare/v2.0.0...v2.1.0) (2025-12-11)


### Features

* Add additional optional embed URL params ([#42](https://github.com/camoag/omni-sdk/issues/42)) ([431efc2](https://github.com/camoag/omni-sdk/commit/431efc25165ff4df164595ebe7c23efcb0af258b))

## [2.0.0](https://github.com/camoag/omni-sdk/compare/v1.2.0...v2.0.0) (2025-09-15)


### ⚠ BREAKING CHANGES

* Update pypi publish to run on tag, switch to uv, and black formatting ([#40](https://github.com/camoag/omni-sdk/issues/40))

### Features

* Update pypi publish to run on tag, switch to uv, and black formatting ([#40](https://github.com/camoag/omni-sdk/issues/40)) ([3b8a129](https://github.com/camoag/omni-sdk/commit/3b8a129ce1e08f34ae055ab2ccada7f9cc0e2cbf))

## [1.2.0](https://github.com/camoag/omni-sdk/compare/v1.1.0...v1.2.0) (2025-09-15)


### Features

* Add support for connectionRoles parameter ([#36](https://github.com/camoag/omni-sdk/issues/36)) ([1405132](https://github.com/camoag/omni-sdk/commit/14051325547b761d4691c8cfb12ab83bc9aab925))

## [1.1.0](https://github.com/camoag/omni-sdk/compare/v1.0.1...v1.1.0) (2024-09-18)


### Features

* add support for 'string' filters and adds additional operator types ([#29](https://github.com/camoag/omni-sdk/issues/29)) ([1e832b5](https://github.com/camoag/omni-sdk/commit/1e832b59f96690e380a5c2ae0d5108d50280f4e3))

## [1.0.1](https://github.com/camoag/omni-sdk/compare/v1.0.0...v1.0.1) (2024-07-11)


### Bug Fixes

* bug in dependencies preventing pypi installs. ([#27](https://github.com/camoag/omni-sdk/issues/27)) ([e688d92](https://github.com/camoag/omni-sdk/commit/e688d923dbc04c3c2e9f41d9fb790bca8e8c9e4e))
* updated git org name to proper home ([#26](https://github.com/camoag/omni-sdk/issues/26)) ([98fd413](https://github.com/camoag/omni-sdk/commit/98fd4131a844c3c7805afff721152f993e2a3e1f))

## [1.0.0](https://github.com/camoag/omni-sdk/compare/v0.3.0-alpha...v1.0.0) (2024-07-10)


### Features

* adds helper classes for passing filter search params in embedded dashboards. ([#21](https://github.com/camoag/omni-sdk/issues/21)) ([5147dba](https://github.com/camoag/omni-sdk/commit/5147dba3fa51394e438ce6903a9baaa87f4d2278))


### Miscellaneous Chores

* release 1.0.0 ([5e495ad](https://github.com/camoag/omni-sdk/commit/5e495add0d01b0e5d5503dd756b96ea50012de87))

## [0.3.0-alpha](https://github.com/camoag/omni-sdk/compare/v0.2.0-alpha...v0.3.0-alpha) (2024-07-03)


### Features

* adds REST client with low level request methods and high level method to refresh models. ([#13](https://github.com/camoag/omni-sdk/issues/13)) ([cf45a30](https://github.com/camoag/omni-sdk/commit/cf45a308443e7544a85d388f56cb56043b831a8e))


### Documentation

* add spra85 as a contributor for doc, and code ([#18](https://github.com/camoag/omni-sdk/issues/18)) ([51392f9](https://github.com/camoag/omni-sdk/commit/51392f9147a467949e40c7d8b2464fdf91e85e03))

## [0.2.0-alpha](https://github.com/camoag/omni-sdk/compare/v0.1.1-alpha...v0.2.0-alpha) (2024-07-01)


### Features

* support embedding urls using a vanity domain ([#15](https://github.com/camoag/omni-sdk/issues/15)) ([1d23d68](https://github.com/camoag/omni-sdk/commit/1d23d68ac570e77d50b45e0fe3e11b3a7832424b))

## [0.1.1-alpha](https://github.com/camoag/omni-sdk/compare/v0.1.0-alpha...v0.1.1-alpha) (2024-06-24)


### Bug Fixes

* fixes broken signatures when url embedder was given an empty string or dict for the filter_search_params. ([#12](https://github.com/camoag/omni-sdk/issues/12)) ([a4bc701](https://github.com/camoag/omni-sdk/commit/a4bc701e5c43da0018017d39332bf6c618f7c636))
* resolve issue with docs automation ([#2](https://github.com/camoag/omni-sdk/issues/2)) ([21848ab](https://github.com/camoag/omni-sdk/commit/21848ab430c0aac92c189f70fccc92643229ed84))
* resolves another issue with docs build ([#6](https://github.com/camoag/omni-sdk/issues/6)) ([c90cbef](https://github.com/camoag/omni-sdk/commit/c90cbefe5295f13f3870101b5df070f53a1d76df))


### Documentation

* add dtiesling as a contributor for code ([#5](https://github.com/camoag/omni-sdk/issues/5)) ([5a016c9](https://github.com/camoag/omni-sdk/commit/5a016c9c35c772e3d755cf3e972f2172a14febc6))
* Fixes formatting on badges. ([e5d388e](https://github.com/camoag/omni-sdk/commit/e5d388e684505528ee5684d3a498decf6f743366))
* fixes typos in the README and adds docstrings ([#9](https://github.com/camoag/omni-sdk/issues/9)) ([4ae0753](https://github.com/camoag/omni-sdk/commit/4ae07539658edc16f202932cf036936a621263de))
